#!/usr/bin/perl

my %CFG = (
   test_key_1 => '11',  
   test_key_2 => '22',  
);
\%CFG;
